==> phpunit_9.6.15.orig.tar.xz: phpunit-9.6.15/.github/ISSUE_TEMPLATE/2_BUG_PHPUNIT_10.md <==
---
name: 🐞 Bug Report for PHPUnit 10
about: Something is broken in PHPUnit 10, but it works in PHPUnit 9?
labels: type/bug, version/10
---

<!--
- Please do not report an issue for a version of PHPUnit that is no longer supported. A list of currently supported versions of PHPUnit is available at https://phpunit.de/supported-versions.html.
- Please do not report an issue if you are using a version of PHP that is not supported by the version of PHPUnit you are using. A list that shows which version of PHP is supported by which version of PHPUnit is available at https://phpunit.de/supported-versions.html.
- Please do not report an issue if you are not using PHPUnit directly, but rather a third-party wrapper around it.
- Please do not report an issue if you are using a third-party extension such as alternative output printers.
- Please do not report an issue for API changes in internal code (see https://phpunit.de/backward-compatibility.html#internal-code).
- Please fill in this template according to your issue.
- Please keep the table shown below at the top of your issue.
- Please include the output of "composer info | sort" if you installed PHPUnit using Composer.
- Please post code as text (using proper markup). Do not post screenshots of code.
- Please remove this comment before submitting your issue.
-->

| Q                   | A
| --------------------| ---------------
| PHPUnit version     | x.y.z
| PHP version         | x.y.z
| Installation Method | Composer / PHAR

#### Summary

<!-- Provide a summary describing the problem you are experiencing. -->

#### Current behavior

<!-- What is the current (buggy) behavior? -->

#### How to reproduce

<!-- Provide steps to reproduce the bug. -->

#### Expected behavior

<!-- What was the expected (correct) behavior? -->

==> phpunit_10.0.12.orig.tar.xz: phpunit-10.0.12/.github/ISSUE_TEMPLATE/2_BUG_PHPUNIT_10.md <==
---
name: 🐞 Bug Report for PHPUnit 10
about: Something is broken in PHPUnit 10, but it works in PHPUnit 9?
labels: type/bug, version/10
---

<!--
- Please do not report an issue for a version of PHPUnit that is no longer supported. A list of currently supported versions of PHPUnit is available at https://phpunit.de/supported-versions.html.
- Please do not report an issue if you are using a version of PHP that is not supported by the version of PHPUnit you are using. A list that shows which version of PHP is supported by which version of PHPUnit is available at https://phpunit.de/supported-versions.html.
- Please do not report an issue if you are not using PHPUnit directly, but rather a wrapper around it such as Symfony's PHPUnit Bridge
- Please fill in this template according to your issue.
- Please keep the table shown below at the top of your issue.
- Please include the output of "composer info | sort" if you installed PHPUnit using Composer.
- Please post code as text (using proper markup). Do not post screenshots of code.
- Visit https://phpunit.de/support.html if you are looking for support.
- Please remove this comment before submitting your issue.
-->

| Q                   | A
| --------------------| ---------------
| PHPUnit version     | x.y.z
| PHP version         | x.y.z
| Installation Method | Composer / PHAR

#### Summary

<!-- Provide a summary describing the problem you are experiencing. -->

#### Current behavior

<!-- What is the current (buggy) behavior? -->

#### How to reproduce

<!-- Provide steps to reproduce the bug. -->

#### Expected behavior

<!-- What was the expected (correct) behavior? -->
